Gratka.pl - ogłoszenia w internecie
Description: Serwis ogłoszeniowy Gratka.pl
Keywords: Gratka, ogłoszenia

Witryna korzysta z plików cookies oraz informacji zapisywanych i odczytywanych z localStorage, aby dopasować interesujące treści oraz reklamy. Korzystanie z serwisu bez zmiany ustawień przeglądarki, w szczególności w zakresie cookies, oznacza, że pliki będą umieszczane na urządzeniu końcowym. Możesz zmienić ustawienia przechowywania i dostępu do cookies i localStorage używając ustawień przeglądarki lub używanego urządzenia. Szczegóły w Polityce Prywatności.

×

Moje konto:

###### Zarejestruj się

- Konto indywidualne
- Konto biznesowe

## Dla kogo jest to konto?

Jeśli prowadzisz firmę na rynku nieruchomości, motoryzacyjnym lub pośrednictwa pracy, bądź też jesteś pracodawcą lub pośrednikiem, to konto jest przeznaczone dla Ciebie.

Dział *

Rynek *

Typ partnera *
Jeśli rozpoczynasz współpracę z dom.gratka.pl zarejestruj się jako "biuro nieruchomości".Jeśli współpracujesz z biurem nieruchomości i chcesz połączyć swoje konto z kontem biura zarejestruj się jako "pośrednik".Jeśli reprezentujesz instytucję, organizację, urząd, biuro kwater lub inną formę działalności związanej z ofertami nieruchomości - załóż konto: "Instytucja, inna działalność".

## Dla kogo jest to konto?

Konto indywidualne przeznaczone jest dla osób prywatnych, które chcą dodać ogłoszenie i nim zarządzać w serwisie Gratka.pl.

E-mail * np. jan.kowalski@domena.pl
Wpisany adres e-mail będzie jednocześnie loginem do konta w Gratka.pl.
Wykorzystasz go do zarządzania swoim kontem, a także ogłoszeniami.

Hasło * Wpisz hasło, które posłuży Ci do logowania
w Gratka.pl. Hasło musi składać się
z co najmniej 6 znaków.

Powtórz hasło * Hasło i powtórzone hasło muszą być identyczne.

Regulamin rozwiń
* Zapoznałem/am się z treścią regulaminu, i akceptuję jego zapisy, w tym informujące o fakcie i zakresie przetwarzania moich danych osobowych przez właściciela serwisów gratka.pl i alegratka.pl - firmę Polskapresse Sp. z o.o. z siedzibą w Warszawie.
Wyrażam zgodę na otrzymywanie drogą elektroniczną na podany adres e-mail informacji handlowych dotyczących usług i produktów własnych oraz partnerów właściciela serwisów gratka.pl i alegratka.pl - firmy Polskapresse Sp. z o.o. z siedzibą w Warszawie.
Wyrażam zgodę na przetwarzanie moich danych osobowych w celach marketingu usług i produktów partnerów właściciela serwisów gratka.pl i alegratka.pl - firmy Polskapresse Sp. z o.o. z siedzibą w Warszawie.
Wyrażam zgodę na przekazywanie moich danych osobowych w niezbędnym zakresie podmiotom trzecim z listy w odnośniku, celem publikacji w mediach tych podmiotów moich ogłoszeń.
* Potwierdzam powyżej zaznaczone zgody i akceptuję regulamin.

*pola obowiązkowe

## Dlaczego warto się zarejestrować?

- Zyskasz łatwy sposób zarządzania Twoimi ogłoszeniami.
- Otrzymasz dostęp do statystyk Twoich ogłoszeń.
- Zachowasz na dłużej wybrane oferty dzięki notesowi.
- Możesz zarządzać powiadomieniami o nowych ofertach.
- Szybciej i taniej dodasz, wyróżnisz Twoje ogłoszenia dzięki pakietom kodów!

## Dlaczego warto się zarejestrować?

Reprezentujesz Biuro Nieruchomości, Firmę z rynku pierwotnego nieruchomości, Autokomis? Chcesz umieszczać oferty na serwisie Gratka.pl? A może chcesz zatrudnić pracownika?
Załóż konto firmowe w Gratka.pl zachowując jednocześnie funkcjonalności i dostęp do konta prywatnego.

Zapoznaj się z ofertą dla firm: Oferta dla firm